summaryrefslogtreecommitdiffstats
path: root/core/membuffer.h
diff options
context:
space:
mode:
authorGravatar Linus Torvalds <torvalds@linux-foundation.org>2019-10-27 14:24:10 -0400
committerGravatar Dirk Hohndel <dirk@hohndel.org>2019-10-27 12:42:54 -0700
commita9b1fbdcc5aba16cb5b5d3acdbbe2b4e48768e1c (patch)
treefd8a32ac646d356c363b0cdc0390e6e7a48441eb /core/membuffer.h
parentd401271dab8d114c74d7d9ceb1ac39290b1a80d8 (diff)
downloadsubsurface-a9b1fbdcc5aba16cb5b5d3acdbbe2b4e48768e1c.tar.gz
Don't expose 'detach_buffer()' to membuffer users
The native buffer of a membuffer is not NUL-terminated, so when you want to detach it and use it as a C string, you had to first do 'mb_cstring()' that adds the proper termination/ This was all documented in the header files, and all but two users did it correctly. But there were those two users, and the exported interface was unnecessarily hard to use. We do want the "just detach the raw buffer" internally in the membuffer code, but let's not make the exported interface be that hard to use. So this switches the exported interface to be 'detach_cstring()', which does that 'mb_cstring()' for you, and avoids the possibility that you'd use a non-terminated memory buffer as a C string. The old 'detach_buffer()' is now purely the internal membuffer implementation, and not used by others. Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
Diffstat (limited to 'core/membuffer.h')
-rw-r--r--core/membuffer.h14
1 files changed, 5 insertions, 9 deletions
diff --git a/core/membuffer.h b/core/membuffer.h
index 03c42a61d..6d497371c 100644
--- a/core/membuffer.h
+++ b/core/membuffer.h
@@ -23,17 +23,13 @@
*
* "something, something else"
*
* Unless ownership to the buffer is given away say to a caller
*
- * mb_cstring(&mb);
- * return detach_buffer(&mb);
- *
- * or via a callback
+ * ptr = detach_cstring();
*
- * mb_cstring(&mb);
- * cb(detach_buffer(&mb));
+ * where the caller now has a C string and is supposed to free it.
*
- * otherwise allocated memory should be freed
+ * Otherwise allocated memory should be freed
*
* free_buffer(&mb);
*/
@@ -60,7 +56,7 @@ struct membuffer {
#define __printf(x, y)
#endif
-extern char *detach_buffer(struct membuffer *b);
+extern char *detach_cstring(struct membuffer *b);
extern void free_buffer(struct membuffer *);
extern void make_room(struct membuffer *b, unsigned int size);
extern void flush_buffer(struct membuffer *, FILE *);
@@ -23,17 +23,13 @@
* "something, something else"
*
- * Unless ownership to the buffer is given away say to a caller
+ * Unless ownership to the buffer is given away by using "detach_cstring()":
*